cato

Module cato |
[hide private]
[frames] | no frames]

# Module cato

source code

This module implements the necessary routines used to embed license informations into source code project files. The package installation also installs a command line utility along with the license files in textual format in a hidden directory inside the user home.

Author: Marco Bartolini

Contact: marco.bartolini@gmail.com

Version: 1.0

Classes | [hide private]
| Cato

Functions | [hide private]
command_line_util(args) Function that parses command line options and invokes cato methods on selected files. | source code

Variables | [hide private]
| __package__ = `None`

Function Details | [hide private]

### command_line_util(args) | source code
Function that parses command line options and invokes cato methods on selected files. Use --help for online help.